macro_rules! impl_cmov_traits_for_signed_ints {
( $($int:ty => $uint:ty),+ ) => { ... };
}Expand description
Impl Cmov* by first casting to unsigned then using the unsigned Cmov impls
macro_rules! impl_cmov_traits_for_signed_ints {
( $($int:ty => $uint:ty),+ ) => { ... };
}Impl Cmov* by first casting to unsigned then using the unsigned Cmov impls